@@ -1,5 +1,4 @@
 import uuid
-import json
 
 from logger.src.common.enums.platform import Platform
 
@@ -13,6 +12,3 @@ class Payload:
         self.message = message
         self.tag = tags
         self.detail = detail
-
-    def toJSON(self):
-        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=True, indent=4)
