@@ -122,5 +122,5 @@ with requests.Session() as session:
 
     def create_log(payload):
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
-                                data=payload)
+                                data=jsonpickle.encode(payload))
         return response
